@@ -6,11 +6,11 @@ WWW::Mechanize - Handy web browsing in a Perl object
 
 =head1 VERSION
 
-Version 1.49_01
+Version 1.51_01
 
 =cut
 
-our $VERSION = '1.49_01';
+our $VERSION = '1.51_01';
 
 =head1 SYNOPSIS
 
@@ -147,9 +147,18 @@ parms that L<LWP::UserAgent> recognizes.
 
 =item * C<< autocheck => [0|1] >>
 
-Checks each request made to see if it was successful.  This saves you
-the trouble of manually checking yourself.  Any errors found are errors,
-not warnings.  Default is ON.
+Checks each request made to see if it was successful.  This saves
+you the trouble of manually checking yourself.  Any errors found
+are errors, not warnings.
+
+The default value is ON, unless it's being subclassed, in which
+case it is OFF.  This means that standalone L<WWW::Mechanize>instances
+have autocheck turned on, which is protective for the vast majority
+of Mech users who don't bother checking the return value of get()
+and post() and can't figure why their code fails. However, if
+L<WWW::Mechanize> is subclassed, such as for L<Test::WWW::Mechanize>
+or L<Test::WWW::Mechanize::Catalyst>, this may not be an appropriate
+default, so it's off.
 
 =item * C<< noproxy => [0|1] >>
 
@@ -204,7 +213,7 @@ sub new {
     );
 
     my %mech_parms = (
-        autocheck   => 1,
+        autocheck   => ($class eq 'WWW::Mechanize' ? 1 : 0),
         onwarn      => \&WWW::Mechanize::_warn,
         onerror     => \&WWW::Mechanize::_die,
         quiet       => 0,
@@ -426,7 +435,17 @@ would it do if it could?)
 
 sub back {
     my $self = shift;
-    $self->_pop_page_stack;
+
+    my $stack = $self->{page_stack};
+    return unless $stack && @{$stack};
+
+    my $popped = pop @{$self->{page_stack}};
+    my $req    = $popped->{req};
+    my $res    = $popped->{res};
+
+    $self->_update_page( $req, $res );
+
+    return 1;
 }
 
 =head1 STATUS METHODS
@@ -460,7 +479,8 @@ Synonym for C<< $mech->response() >>
 
 =head2 $mech->status()
 
-Returns the HTTP status code of the response.
+Returns the HTTP status code of the response.  This is a 3-digit
+number like 200 for OK, 404 for not found, and so on.
 
 =head2 $mech->ct()
 
@@ -2452,7 +2472,7 @@ sub _link_from_token {
         });
 } # _link_from_token
 
-=head2 $mech->_push_page_stack() / $mech->_pop_page_stack()
+=head2 $mech->_push_page_stack()
 
 The agent keeps a stack of visited pages, which it can pop when it needs
 to go BACK and so on.
@@ -2468,39 +2488,17 @@ object.
 sub _push_page_stack {
     my $self = shift;
 
+    my $req = $self->{req};
+    my $res = $self->{res};
+
+    return unless $req && $res && $self->stack_depth;
+
     # Don't push anything if it's a virgin object
-    if ( $self->{res} && $self->stack_depth ) {
-        my $save_stack = $self->{page_stack};
-        $self->{page_stack} = [];
-
-        my $clone = $self->clone;
-        push( @{$save_stack}, $clone );
-
-        while ( @{$save_stack} > $self->stack_depth ) {
-            shift @{$save_stack};
-        }
-        $self->{page_stack} = $save_stack;
-    }
-
-    return 1;
-}
-
-sub _pop_page_stack {
-    my $self = shift;
-
-    if ( $self->{page_stack} && @{$self->{page_stack}} ) {
-        my $popped = pop @{$self->{page_stack}};
-
-        # eliminate everything in self
-        foreach my $key ( keys %{$self} ) {
-            delete $self->{ $key }              unless $key eq 'page_stack';
-        }
-
-        # make self just like the popped object
-        foreach my $key ( keys %{$popped} ) {
-            $self->{ $key } = $popped->{ $key } unless $key eq 'page_stack';
-        }
+    my $stack = $self->{page_stack} ||= [];
+    if ( @{$stack} >= $self->stack_depth ) {
+        shift @{$stack};
     }
+    push( @{$stack}, { req => $req, res => $res } );
 
     return 1;
 }
